@@ -14,7 +14,7 @@ use English qw/ -no_match_vars /;
 
 extends 'App::VTide::Command::Run';
 
-our $VERSION = version->new('0.0.7');
+our $VERSION = version->new('0.0.8');
 our $NAME    = 'edit';
 our $OPTIONS = [
     'test|T!',
@@ -45,11 +45,15 @@ sub run {
     $self->hooks->run('edit_editing', \@cmd);
     $self->runit( @cmd );
 
+    $params = $self->params($ENV{VTIDE_TERM});
+    eval { require Term::Title; }
+        and Term::Title::set_titlebar($params->{title} || 'bash');
+
     return;
 }
 
 sub auto_complete {
-    my ($self) = @_;
+    my ($self, $auto) = @_;
 
     my $env = $self->options->files->[-1];
     my @files = sort keys %{ $self->config->get->{editor}{files} };
@@ -58,7 +62,7 @@ sub auto_complete {
         my $helper = $self->config->get->{editor}{helper_autocomplete};
         if ($helper) {
             $helper = eval $helper;  ## no critic
-            push @files, $helper->();
+            push @files, $helper->($auto, $self->options->files);
         }
         1;
     } or do { warn $@ };
@@ -78,7 +82,7 @@ App::VTide::Command::Edit - Run an edit command (like Run but without a terminal
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Edit version 0.0.7
+This documentation refers to App::VTide::Command::Edit version 0.0.8
 
 =head1 SYNOPSIS
 
