@@ -18,7 +18,7 @@ use File::chdir;
 
 extends 'App::VTide::Command';
 
-our $VERSION = version->new('0.0.7');
+our $VERSION = version->new('0.0.8');
 our $NAME    = 'run';
 our $OPTIONS = [
     'name|n=s',
@@ -65,7 +65,16 @@ sub run {
             warn "Will wait before starting\n" if $params->{wait};
             warn "Will restart on exit\n" if $params->{restart};
         }
+
+        # run any hooks for run_running
         $self->hooks->run('run_running', \@cmd);
+
+        if ( $params->{headding} ) {
+            # show terminal headding if desired
+            print $params->{headding}, "\n";
+        }
+
+        # start the terminal
         $self->runit( @cmd );
     }
 
@@ -307,7 +316,7 @@ App::VTide::Command::Run - Run a terminal command
 
 =head1 VERSION
 
-This documentation refers to App::VTide::Command::Run version 0.0.7
+This documentation refers to App::VTide::Command::Run version 0.0.8
 
 =head1 SYNOPSIS
 
